@@ -58,6 +58,8 @@ from typedpy.fields import (
     ImmutableNumber,
     ImmutableDeque,
     Deque,
+    ExceptionField,
+    Generator,
 )
 
 from typedpy.json_schema_mapping import (
@@ -72,6 +74,7 @@ from .serialization import (
     serialize,
     serialize_field,
     FunctionCall,
+    deserialize_single_field,
 )
 
 from .serialization_wrappers import (
