@@ -1,10 +1,9 @@
 import collections
 import enum
 import json
-from functools import reduce
 from typing import Dict
 
-from .commons import raise_errs_if_needed
+from .commons import deep_get, raise_errs_if_needed
 from .versioned_mapping import VERSION_MAPPING, Versioned, convert_dict
 from .mappers import (
     aggregate_deserialization_mappers,
@@ -256,23 +255,24 @@ def deserialize_single_field(  # pylint: disable=too-many-branches
     ignore_none=False,
 ):
     """
-        Deserialize a field directly, without the need to define a Structure class.
-        Note the top level must be a python dict - which implies that a JSON of
-        Arguments:
-            field(Field):
-                The field definition. For example: String, Array[Map[str, Foo]], AnyOf[Foo, Bar]
-            source_val:
-                the serialized value to be deserialized
-            name(optional):
-                name to be used for the field in case of raised exceptions
-            mapper(dict): optional
-                A Typedpy deserialization mapper
-            keep_undefined(bool): optional
-                should it create attributes for keys that don't appear in the class? default is True.
+    Deserialize a field directly, without the need to define a Structure class.
+    Note the top level must be a python dict - which implies that a JSON of
 
-        Returns:
-            a deserialized version of the data if successful, or raises an appropriate exception
-        """
+    Arguments:
+        field(Field):
+            The field definition. For example: String, Array[Map[str, Foo]], AnyOf[Foo, Bar]
+        source_val:
+            the serialized value to be deserialized
+        name(optional):
+            name to be used for the field in case of raised exceptions
+        mapper(dict): optional
+            A Typedpy deserialization mapper
+        keep_undefined(bool): optional
+            should it create attributes for keys that don't appear in the class? default is True.
+
+    Returns:
+        a deserialized version of the data if successful, or raises an appropriate exception
+    """
     if source_val is None and (ignore_none or isinstance(field, NoneField)):
         return source_val
     if isinstance(field, (Number, String, Enum, Boolean)):
@@ -576,14 +576,9 @@ def deserialize_structure(
     )
 
 
-def _deep_get(dictionary, deep_key):
-    keys = deep_key.split(".")
-    return reduce(lambda d, key: d.get(key) if d else None, keys, dictionary)
-
-
 def get_processed_input(key, mapper, the_dict):
     def _try_deep_get(k):
-        v = _deep_get(the_dict, k)
+        v = deep_get(the_dict, k)
         return v if v is not None else k
 
     key_mapper = mapper[key]
@@ -595,7 +590,7 @@ def get_processed_input(key, mapper, the_dict):
         )
         processed_input = key_mapper.func(*args)
     elif isinstance(key_mapper, (str,)):
-        val = _deep_get(the_dict, key_mapper)
+        val = deep_get(the_dict, key_mapper)
         processed_input = val if val is not None else the_dict.get(key)
     else:
         raise TypeError(
@@ -752,7 +747,7 @@ def _get_mapped_value(mapper, key, items):
         key_mapper = mapper[key]
         if isinstance(key_mapper, (FunctionCall,)):
             args = (
-                [_deep_get(items, k) for k in key_mapper.args]
+                [deep_get(items, k) for k in key_mapper.args]
                 if key_mapper.args
                 else [items.get(key)]
             )
