@@ -1,5 +1,6 @@
 import copy
 
+from .commons import deep_get
 from .mappers import Constant, Deleted
 from .structures import Structure
 from .fields import FunctionCall, PositiveInt
@@ -38,11 +39,12 @@ def _convert(mapped_dict: dict, mapping):
             out_dict[k] = v()
         elif k.endswith("._mapper"):
             field_name = k[: -len("._mapper")]
-            content = mapped_dict[field_name]
-            if isinstance(content, list):
-                out_dict[field_name] = [_convert(x, v) for x in content]
-            else:
-                out_dict[field_name] = _convert(content, v)
+            content = mapped_dict.get(field_name, None)
+            if content is not None:
+                if isinstance(content, list):
+                    out_dict[field_name] = [_convert(x, v) for x in content]
+                else:
+                    out_dict[field_name] = _convert(content, v)
 
         elif isinstance(v, FunctionCall):
             args = [out_dict[x] for x in v.args] if v.args else [out_dict[k]]
@@ -50,7 +52,7 @@ def _convert(mapped_dict: dict, mapping):
 
     for k, v in mapping.items():
         if isinstance(v, str):
-            out_dict[k] = out_dict[v]
+            out_dict[k] = deep_get(out_dict, v)
 
     for k, v in mapping.items():
         if v == Deleted:
